@@ -4,13 +4,13 @@ from numpy.random import choice
 from textwrap import dedent
 from random import Random
 
-from bionic.cache import FakeCloudStore
 from bionic.exception import CodeVersioningError
+from bionic.persistence import FakeCloudStore
 from bionic import interpret
 import bionic as bn
 
 
-class SimpleFlowModel(object):
+class SimpleFlowModel:
     """
     Manages a simple Bionic flow where every entity value is an integer
     computed from the sum of other entity values.  This wrapper class maintains
@@ -19,11 +19,13 @@ class SimpleFlowModel(object):
     validate large flows.
     """
 
-    def __init__(self, builder):
+    def __init__(self, builder, make_list):
         self._builder = builder
+        self._current_flow = None
+        self._update_flow()
 
         self._entities_by_name = {}
-        self._last_called_names = []
+        self._last_called_names = make_list()
 
     def add_entity(self, dep_names, nondeterministic=False):
         name = f"e{len(self._entities_by_name) + 1}"
@@ -55,8 +57,8 @@ class SimpleFlowModel(object):
 
         self._define_entity(name)
 
-    def build_flow(self):
-        return self._builder.build()
+    def get_flow(self):
+        return self._current_flow
 
     def expected_entity_value(self, name):
         entity = self._entities_by_name[name]
@@ -120,7 +122,7 @@ class SimpleFlowModel(object):
 
     def called_entity_names(self):
         names = list(self._last_called_names)
-        self._last_called_names.clear()
+        self.reset_called_entity_names()
         return names
 
     def peek_called_entity_names(self):
@@ -128,7 +130,7 @@ class SimpleFlowModel(object):
         return names
 
     def reset_called_entity_names(self):
-        self._last_called_names.clear()
+        self._last_called_names[:] = []
 
     def _create_entity(self, name, dep_names, is_nondeterministic):
         entity = ModelEntity(
@@ -178,8 +180,13 @@ class SimpleFlowModel(object):
             vars_dict,
         )
 
+        self._update_flow()
 
-class ModelEntity(object):
+    def _update_flow(self):
+        self._current_flow = self._builder.build()
+
+
+class ModelEntity:
     """
     Represents one entity in the SimpleFlowModel.
     """
@@ -200,14 +207,14 @@ class ModelEntity(object):
         self.all_downstream_names = set()
 
 
-class Fuzzer(object):
+class Fuzzer:
     """
     Randomly constructs and updates a SimpleModelFlow while checking that its
     behavior is as expected.
     """
 
-    def __init__(self, builder, random_seed=0):
-        self.model = SimpleFlowModel(builder)
+    def __init__(self, builder, make_list, random_seed=0):
+        self.model = SimpleFlowModel(builder, make_list)
         self._versioning_mode = "manual"
         self._builder = builder
         self._random = Random(random_seed)
@@ -227,7 +234,7 @@ class Fuzzer(object):
                     dep_names.append(name)
             new_name = self.model.add_entity(dep_names, is_nondeterministic)
 
-            self.model.build_flow().get(new_name)
+            self.model.get_flow().get(new_name)
             expected_called_names = self.model.nondeterministic_upstream_entity_names(
                 new_name
             )
@@ -268,7 +275,7 @@ class Fuzzer(object):
                     # Bionic doesn't know the code has changed, so this entity
                     # should still be returning the old value.
                     affected_name = self._random.choice(affected_names)
-                    returned_value = self.model.build_flow().get(affected_name)
+                    returned_value = self.model.get_flow().get(affected_name)
                     expected_value = self.model.expected_entity_value(affected_name)
 
                     # When the change is functional and bionic doesn't recompute the
@@ -304,10 +311,10 @@ class Fuzzer(object):
                         # Bionic should detect that we forgot to update the
                         # version.
                         with pytest.raises(CodeVersioningError):
-                            self.model.build_flow().get(affected_name)
+                            self.model.get_flow().get(affected_name)
                     else:
                         # Version does not matter for nondeterministic entities.
-                        assert self.model.build_flow().get(
+                        assert self.model.get_flow().get(
                             affected_name
                         ) == self.model.expected_entity_value(affected_name)
 
@@ -331,7 +338,7 @@ class Fuzzer(object):
                     )
 
             for affected_name in affected_names:
-                assert self.model.build_flow().get(
+                assert self.model.get_flow().get(
                     affected_name
                 ) == self.model.expected_entity_value(affected_name)
 
@@ -376,10 +383,10 @@ class Fuzzer(object):
 
 
 @pytest.fixture(scope="function")
-def fuzzer(builder, tmp_path):
+def fuzzer(builder, make_list, tmp_path):
     fake_cloud_store = FakeCloudStore(str(tmp_path / "BNTESTDATA_FAKE_CLOUD"))
     builder.set("core__persistent_cache__cloud_store", fake_cloud_store)
-    return Fuzzer(builder)
+    return Fuzzer(builder, make_list)
 
 
 foreach_mode = pytest.mark.parametrize("versioning_mode", ["manual", "assist", "auto"])
@@ -395,7 +402,7 @@ def test_small_fixed_flow_short_fuzz(fuzzer, versioning_mode):
     e4 = fuzzer.model.add_entity([e1, e2])
     e5 = fuzzer.model.add_entity([e3, e4])
 
-    assert fuzzer.model.build_flow().get(e5) == fuzzer.model.expected_entity_value(e5)
+    assert fuzzer.model.get_flow().get(e5) == fuzzer.model.expected_entity_value(e5)
     assert list(sorted(fuzzer.model.called_entity_names())) == list(
         sorted(fuzzer.model.entity_names())
     )
